@@ -90,7 +90,6 @@ void TextInputTest::init()
     m_seatInterface->setHasTouch(true);
     m_seatInterface->create();
     m_compositorInterface = m_display->createCompositor();
-    m_compositorInterface->create();
     m_textInputManagerV0Interface = m_display->createTextInputManager(TextInputInterfaceVersion::UnstableV0);
     m_textInputManagerV0Interface->create();
     m_textInputManagerV2Interface = m_display->createTextInputManager(TextInputInterfaceVersion::UnstableV2);
@@ -296,13 +295,6 @@ void TextInputTest::testEnterLeave()
     textInput->enable(surface.data());
     QVERIFY(enabledChangedSpy.wait());
 
-    //trigger an enter again and leave, but this
-    //time we try sending an event after the surface is unbound
-    //but not yet destroyed. It should work without errors
-    QCOMPARE(textInput->enteredSurface(), surface.data());
-    connect(serverSurface, &Resource::unbound, [=]() {
-        m_seatInterface->setFocusedKeyboardSurface(nullptr);
-    });
     //delete the client and wait for the server to catch up
     QSignalSpy unboundSpy(serverSurface, &QObject::destroyed);
     surface.reset();
